/********************************************************************
 File: mlx_usb.h

 Description:
 This file contains defines for mlx/usb functions.

 Authors and Copyright:
 (c) 2018, Thomas Fischl (http://www.fischl.de/contact.html)

 Device: PIC16LF1455
 Compiler: Microchip MPLAB XC8 C Compiler V1.44

 License:
 This file is part of the USBtin firmware project and is copyrighted by the
 authors listed above. It is free for private or educational non-commercial use
 (for a commercial license please contact the authors). It may not be
 redistributed without the prior written consent of the authors.
 
 It is provided "as is" without warranty of any kind, either express or implied,
 including without limitation any implied warranties of condition, uninterrupted
 use, merchantability, fitness for a particular purpose, or non-infringement. In
 no event shall the authors be liable for any direct or indirect damages arising
 in any way out of the use of it.
 
 ********************************************************************/

#ifndef MLX_USB_H
#define	MLX_USB_H

void mlx_usb_init();
void mlx_usb_process();
unsigned char mlx_writeRegister(unsigned char devaddress, unsigned short regaddress, unsigned short value);

struct mem_access_cmd {
    unsigned char type;
    unsigned char cmd;
    unsigned short deviceaddress;
    unsigned short memoryaddress;
    unsigned short length;  
};

#define CMD_GET_CAPABILITY   0
#define CMD_ECHO             1
#define CMD_START_BOOTLOADER 2
#define CMD_READ_MEMORY      3
#define CMD_WRITE_MEMORY     4
#define CMD_GET_STATUS       5
#define CMD_CONFIG_BFMODE    6


#define STATUS_IDLE          0
#define STATUS_ADDRESS_ACK   1
#define STATUS_ADDRESS_NAK   2


#define MLX_REGISTER_STATUS 0x8000
#define MLX_REGISTER_CONFIG 0x800D
#define MLX_RAM_PIXELDATA_START 0x0400
#define MLX_RAM_PIXELDATA_END 0x06FF

#define MLX_BT_DEVADDRESS_INVALID 0xff

#endif

